@@ -145,16 +145,16 @@ class ReservationServiceGrpcAsyncIOTransport(ReservationServiceTransport):
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
-                ``client_cert_source`` or applicatin default SSL credentials.
+                ``client_cert_source`` or application default SSL credentials.
             client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 Deprecated. A callback to provide client SSL certificate bytes and
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 A callback to provide client certificate bytes and private key bytes,
-                both in PEM format. It is used to configure mutual TLS channel. It is
+                both in PEM format. It is used to configure a mutual TLS channel. It is
                 ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
@@ -653,6 +653,12 @@ class ReservationServiceGrpcAsyncIOTransport(ReservationServiceTransport):
            ``project1``, and ``project2``) could all be created and
            mapped to the same or different reservations.
 
+        "None" assignments represent an absence of the assignment.
+        Projects assigned to None use on-demand pricing. To create a
+        "None" assignment, use "none" as a reservation_id in the parent.
+        Example parent:
+        ``projects/myproject/locations/US/reservations/none``.
+
         Returns ``google.rpc.Code.PERMISSION_DENIED`` if user does not
         have 'bigquery.admin' permissions on the project using the
         reservation and the project that owns this reservation.
@@ -778,8 +784,8 @@ class ReservationServiceGrpcAsyncIOTransport(ReservationServiceTransport):
     ]:
         r"""Return a callable for the search assignments method over gRPC.
 
-        Looks up assignments for a specified resource for a particular
-        region. If the request is about a project:
+        Deprecated: Looks up assignments for a specified resource for a
+        particular region. If the request is about a project:
 
         1. Assignments created on the project will be returned if they
            exist.
@@ -822,6 +828,57 @@ class ReservationServiceGrpcAsyncIOTransport(ReservationServiceTransport):
             )
         return self._stubs["search_assignments"]
 
+    @property
+    def search_all_assignments(
+        self,
+    ) -> Callable[
+        [reservation.SearchAllAssignmentsRequest],
+        Awaitable[reservation.SearchAllAssignmentsResponse],
+    ]:
+        r"""Return a callable for the search all assignments method over gRPC.
+
+        Looks up assignments for a specified resource for a particular
+        region. If the request is about a project:
+
+        1. Assignments created on the project will be returned if they
+           exist.
+        2. Otherwise assignments created on the closest ancestor will be
+           returned.
+        3. Assignments for different JobTypes will all be returned.
+
+        The same logic applies if the request is about a folder.
+
+        If the request is about an organization, then assignments
+        created on the organization will be returned (organization
+        doesn't have ancestors).
+
+        Comparing to ListAssignments, there are some behavior
+        differences:
+
+        1. permission on the assignee will be verified in this API.
+        2. Hierarchy lookup (project->folder->organization) happens in
+           this API.
+        3. Parent here is ``projects/*/locations/*``, instead of
+           ``projects/*/locations/*reservations/*``.
+
+        Returns:
+            Callable[[~.SearchAllAssignmentsRequest],
+                    Awaitable[~.SearchAllAssignmentsResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "search_all_assignments" not in self._stubs:
+            self._stubs["search_all_assignments"] = self.grpc_channel.unary_unary(
+                "/google.cloud.bigquery.reservation.v1.ReservationService/SearchAllAssignments",
+                request_serializer=reservation.SearchAllAssignmentsRequest.serialize,
+                response_deserializer=reservation.SearchAllAssignmentsResponse.deserialize,
+            )
+        return self._stubs["search_all_assignments"]
+
     @property
     def move_assignment(
         self,
@@ -917,5 +974,8 @@ class ReservationServiceGrpcAsyncIOTransport(ReservationServiceTransport):
             )
         return self._stubs["update_bi_reservation"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("ReservationServiceGrpcAsyncIOTransport",)
