@@ -35,6 +35,8 @@ from .reservation import (
     MergeCapacityCommitmentsRequest,
     MoveAssignmentRequest,
     Reservation,
+    SearchAllAssignmentsRequest,
+    SearchAllAssignmentsResponse,
     SearchAssignmentsRequest,
     SearchAssignmentsResponse,
     SplitCapacityCommitmentRequest,
@@ -66,6 +68,8 @@ __all__ = (
     "MergeCapacityCommitmentsRequest",
     "MoveAssignmentRequest",
     "Reservation",
+    "SearchAllAssignmentsRequest",
+    "SearchAllAssignmentsResponse",
     "SearchAssignmentsRequest",
     "SearchAssignmentsResponse",
     "SplitCapacityCommitmentRequest",
