@@ -46,7 +46,9 @@ __protobuf__ = proto.module(
         "ListAssignmentsResponse",
         "DeleteAssignmentRequest",
         "SearchAssignmentsRequest",
+        "SearchAllAssignmentsRequest",
         "SearchAssignmentsResponse",
+        "SearchAllAssignmentsResponse",
         "MoveAssignmentRequest",
         "BiReservation",
         "GetBiReservationRequest",
@@ -77,16 +79,26 @@ class Reservation(proto.Message):
             capacity, the request will fail with
             ``google.rpc.Code.RESOURCE_EXHAUSTED``.
         ignore_idle_slots (bool):
-            If false, any query using this reservation
-            will use idle slots from other reservations
-            within the same admin project. If true, a query
-            using this reservation will execute with the
-            slot capacity specified above at most.
+            If false, any query or pipeline job using this reservation
+            will use idle slots from other reservations within the same
+            admin project. If true, a query or pipeline job using this
+            reservation will execute with the slot capacity specified in
+            the slot_capacity field at most.
+        creation_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. Creation time of the
+            reservation.
+        update_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. Last update time of the
+            reservation.
     """
 
     name = proto.Field(proto.STRING, number=1,)
     slot_capacity = proto.Field(proto.INT64, number=2,)
     ignore_idle_slots = proto.Field(proto.BOOL, number=4,)
+    creation_time = proto.Field(
+        proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(proto.MESSAGE, number=9, message=timestamp_pb2.Timestamp,)
 
 
 class CapacityCommitment(proto.Message):
@@ -112,6 +124,10 @@ class CapacityCommitment(proto.Message):
             Capacity commitment commitment plan.
         state (google.cloud.bigquery_reservation_v1.types.CapacityCommitment.State):
             Output only. State of the commitment.
+        commitment_start_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The start of the current
+            commitment period. It is applicable only for
+            ACTIVE capacity commitments.
         commitment_end_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The end of the current
             commitment period. It is applicable only for
@@ -150,6 +166,9 @@ class CapacityCommitment(proto.Message):
     slot_count = proto.Field(proto.INT64, number=2,)
     plan = proto.Field(proto.ENUM, number=3, enum=CommitmentPlan,)
     state = proto.Field(proto.ENUM, number=4, enum=State,)
+    commitment_start_time = proto.Field(
+        proto.MESSAGE, number=9, message=timestamp_pb2.Timestamp,
+    )
     commitment_end_time = proto.Field(
         proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
     )
@@ -279,6 +298,14 @@ class CreateCapacityCommitmentRequest(proto.Message):
         enforce_single_admin_project_per_org (bool):
             If true, fail the request if another project
             in the organization has a capacity commitment.
+        capacity_commitment_id (str):
+            The optional capacity commitment ID. Capacity
+            commitment name will be generated automatically
+            if this field is empty. This field must only
+            contain lower case alphanumeric characters or
+            dash. Max length is 64 characters.
+            NOTE: this ID won't be kept if the capacity
+            commitment is split or merged.
     """
 
     parent = proto.Field(proto.STRING, number=1,)
@@ -286,6 +313,7 @@ class CreateCapacityCommitmentRequest(proto.Message):
         proto.MESSAGE, number=2, message="CapacityCommitment",
     )
     enforce_single_admin_project_per_org = proto.Field(proto.BOOL, number=4,)
+    capacity_commitment_id = proto.Field(proto.STRING, number=5,)
 
 
 class ListCapacityCommitmentsRequest(proto.Message):
@@ -355,9 +383,15 @@ class DeleteCapacityCommitmentRequest(proto.Message):
             Required. Resource name of the capacity commitment to
             delete. E.g.,
             ``projects/myproject/locations/US/capacityCommitments/123``
+        force (bool):
+            Can be used to force delete commitments even
+            if assignments exist. Deleting commitments with
+            assignments may cause queries to fail if they no
+            longer have access to slots.
     """
 
     name = proto.Field(proto.STRING, number=1,)
+    force = proto.Field(proto.BOOL, number=3,)
 
 
 class UpdateCapacityCommitmentRequest(proto.Message):
@@ -460,6 +494,7 @@ class Assignment(proto.Message):
         JOB_TYPE_UNSPECIFIED = 0
         PIPELINE = 1
         QUERY = 2
+        ML_EXTERNAL = 3
 
     class State(proto.Enum):
         r"""Assignment will remain in PENDING state if no active capacity
@@ -488,10 +523,17 @@ class CreateAssignmentRequest(proto.Message):
             ``projects/myproject/locations/US/reservations/team1-prod``
         assignment (google.cloud.bigquery_reservation_v1.types.Assignment):
             Assignment resource to create.
+        assignment_id (str):
+            The optional assignment ID. Assignment name
+            will be generated automatically if this field is
+            empty. This field must only contain lower case
+            alphanumeric characters or dash. Max length is
+            64 characters.
     """
 
     parent = proto.Field(proto.STRING, number=1,)
     assignment = proto.Field(proto.MESSAGE, number=2, message="Assignment",)
+    assignment_id = proto.Field(proto.STRING, number=4,)
 
 
 class ListAssignmentsRequest(proto.Message):
@@ -589,6 +631,39 @@ class SearchAssignmentsRequest(proto.Message):
     page_token = proto.Field(proto.STRING, number=4,)
 
 
+class SearchAllAssignmentsRequest(proto.Message):
+    r"""The request for
+    [ReservationService.SearchAllAssignments][google.cloud.bigquery.reservation.v1.ReservationService.SearchAllAssignments].
+    Note: "bigquery.reservationAssignments.search" permission is
+    required on the related assignee.
+
+    Attributes:
+        parent (str):
+            Required. The resource name with location (project name
+            could be the wildcard '-'), e.g.:
+            ``projects/-/locations/US``.
+        query (str):
+            Please specify resource name as assignee in the query.
+
+            Examples:
+
+            -  ``assignee=projects/myproject``
+            -  ``assignee=folders/123``
+            -  ``assignee=organizations/456``
+        page_size (int):
+            The maximum number of items to return per
+            page.
+        page_token (str):
+            The next_page_token value returned from a previous List
+            request, if any.
+    """
+
+    parent = proto.Field(proto.STRING, number=1,)
+    query = proto.Field(proto.STRING, number=2,)
+    page_size = proto.Field(proto.INT32, number=3,)
+    page_token = proto.Field(proto.STRING, number=4,)
+
+
 class SearchAssignmentsResponse(proto.Message):
     r"""The response for
     [ReservationService.SearchAssignments][google.cloud.bigquery.reservation.v1.ReservationService.SearchAssignments].
@@ -610,6 +685,27 @@ class SearchAssignmentsResponse(proto.Message):
     next_page_token = proto.Field(proto.STRING, number=2,)
 
 
+class SearchAllAssignmentsResponse(proto.Message):
+    r"""The response for
+    [ReservationService.SearchAllAssignments][google.cloud.bigquery.reservation.v1.ReservationService.SearchAllAssignments].
+
+    Attributes:
+        assignments (Sequence[google.cloud.bigquery_reservation_v1.types.Assignment]):
+            List of assignments visible to the user.
+        next_page_token (str):
+            Token to retrieve the next page of results,
+            or empty if there are no more results in the
+            list.
+    """
+
+    @property
+    def raw_page(self):
+        return self
+
+    assignments = proto.RepeatedField(proto.MESSAGE, number=1, message="Assignment",)
+    next_page_token = proto.Field(proto.STRING, number=2,)
+
+
 class MoveAssignmentRequest(proto.Message):
     r"""The request for
     [ReservationService.MoveAssignment][google.cloud.bigquery.reservation.v1.ReservationService.MoveAssignment].
@@ -636,11 +732,12 @@ class MoveAssignmentRequest(proto.Message):
 
 class BiReservation(proto.Message):
     r"""Represents a BI Reservation.
+
     Attributes:
         name (str):
             The resource name of the singleton BI reservation.
             Reservation names have the form
-            ``projects/{project_id}/locations/{location_id}/bireservation``.
+            ``projects/{project_id}/locations/{location_id}/biReservation``.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The last update timestamp of a
             reservation.
@@ -655,10 +752,11 @@ class BiReservation(proto.Message):
 
 class GetBiReservationRequest(proto.Message):
     r"""A request to get a singleton BI reservation.
+
     Attributes:
         name (str):
             Required. Name of the requested reservation, for example:
-            ``projects/{project_id}/locations/{location_id}/bireservation``
+            ``projects/{project_id}/locations/{location_id}/biReservation``
     """
 
     name = proto.Field(proto.STRING, number=1,)
@@ -666,6 +764,7 @@ class GetBiReservationRequest(proto.Message):
 
 class UpdateBiReservationRequest(proto.Message):
     r"""A request to update a BI reservation.
+
     Attributes:
         bi_reservation (google.cloud.bigquery_reservation_v1.types.BiReservation):
             A reservation to update.
